# an example project

This example project results in a tested, full-stack python application:

- a conda-managed environment
- a python-based web server application
  - that generates an OpenAPI spec
  - tested with pytest
- a JS-based client
  - with a generated API client
  - tested with jest
  - deployed to the python application
- documentation
- robot framework tests
